/*
 * colorized_text.cpp
 *
 * Copyright (C) 2003 Ed Cogburn <ecogburn@xtn.net>
 *
 * This file is part of the program "d: The Directory Lister".
 *
 * "d: The Directory Lister" is free software; you can redistribute it and/or modify it under the terms of the GNU General Public
 * License as published by the Free Software Foundation; either version 2 of the License, or (at your option) any later version.
 *
 * "d: The Directory Lister" is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied
 * warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along with "d: The Directory Lister" in a file named "COPYING".
 * If not, visit their website at http://www.gnu.org for a copy, or request a copy by writing to:
 *     Free Software Foundation, Inc.
 *     59 Temple Place, Suite 330
 *     Boston, MA 02111-1307 USA
*/



#include "globals.hpp"



namespace ct
{



	//-----------------------------------------------------------------------------
	string colorized_text::set(Color cf, Color cb, Attr a)
	{
		string tmp;

		tmp = "\x1B[";

		switch (a)	{
			case aNormal:
				tmp += "00;";
				break;

			case aBold:
				tmp += "01;";
				break;

			case aUnderline:
				tmp += "04;";
				break;

			case aBlink:
				tmp += "05;";
				break;

			case aReverse:
				tmp += "07;";
				break;

			default:
				throw runtime_error("colorized_text():  Unknown attribute!");
		}

		switch (cf)	{
			case cBlack:
				tmp += "30;";
				break;

			case cRed:
				tmp += "31;";
				break;

			case cGreen:
				tmp += "32;";
				break;

			case cYellow:
				tmp += "33;";
				break;

			case cBlue:
				tmp += "34;";
				break;

			case cMagenta:
				tmp += "35;";
				break;

			case cCyan:
				tmp += "36;";
				break;

			case cWhite:
				tmp += "37;";
				break;

			default:
				throw runtime_error("colorized_text():  Unknown foreground color!");
		}

		switch (cb)	{
			case cBlack:
				tmp += "40";
				break;

			case cRed:
				tmp += "41";
				break;

			case cGreen:
				tmp += "42";
				break;

			case cYellow:
				tmp += "43";
				break;

			case cBlue:
				tmp += "44";
				break;

			case cMagenta:
				tmp += "45";
				break;

			case cCyan:
				tmp += "46";
				break;

			case cWhite:
				tmp += "47";
				break;

			default:
				throw runtime_error("colorized_text():  Unknown background color!");
		}

		tmp += "m";

		return tmp;
	}



	//-----------------------------------------------------------------------------
	string colorized_text::reset()
	{
		return "\x1B[0m";
	}



} // namespace ct
